scilpy.segment package
======================

scilpy.segment.models module
------------------------------------------------------

.. automodule:: scilpy.segment.models
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.segment.recobundlesx module
------------------------------------------------------

.. automodule:: scilpy.segment.recobundlesx
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.segment.streamlines module
------------------------------------------------------

.. automodule:: scilpy.segment.streamlines
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.segment.tractogram\_from\_roi module
------------------------------------------------------

.. automodule:: scilpy.segment.tractogram_from_roi
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.segment.voting\_scheme module
------------------------------------------------------

.. automodule:: scilpy.segment.voting_scheme
   :members:
   :undoc-members:
   :show-inheritance:
